==> abinit_7.8.2.orig.tar.gz: abinit-7.8.2/doc/users/list_internal_links.js <==
document.write(' <HR ALIGN=left> ');
document.write(' Goto :          ');
document.write(' <A href="http://www.abinit.org"><B>ABINIT home Page</B></A>          ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/acknowledgments.html"><B>Suggested acknowledgments</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../input_variables/keyhr.html"><B>List of input variables</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../tutorial/welcome.html"><B>Tutorial home page</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/bibliography.html"><B>Bibliography</B></A> ');
document.write(' <HR ALIGN=left> ');
document.write(' Help files : ');
document.write(' <A href="../users/new_user_guide.html"><B>New user guide</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/abinit_help.html"><B>Abinit (main)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/respfn_help.html"><B>Abinit (respfn)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/mrgddb_help.html"><B>Mrgddb</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/anaddb_help.html"><B>Anaddb</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/aim_help.html"><B>AIM (Bader)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/cut3d_help.html"><B>Cut3D</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/optic_help.html"><B>Optic</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/mrgscr_help.html"><B>Mrgscr</B></A> ');
document.write(' <HR ALIGN=left> ');

==> abinit_8.0.8.orig.tar.gz: abinit-8.0.8/doc/users/list_internal_links.js <==
document.write(' <HR ALIGN=left> ');
document.write(' Goto :          ');
document.write(' <A href="http://www.abinit.org"><B>ABINIT home Page</B></A>          ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/acknowledgments.html"><B>Suggested acknowledgments</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../input_variables/html_automatically_generated/allvariables.html"><B>List of input variables</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../tutorial/welcome.html"><B>Tutorial home page</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/bibliography.html"><B>Bibliography</B></A> ');
document.write(' <HR ALIGN=left> ');
document.write(' Help files : ');
document.write(' <A href="../users/new_user_guide.html"><B>Guide for new users</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/abinit_help.html"><B>Abinit (main)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/respfn_help.html"><B>Abinit (respfn)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/mrgddb_help.html"><B>Mrgddb</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/anaddb_help.html"><B>Anaddb</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/aim_help.html"><B>AIM (Bader)</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/cut3d_help.html"><B>Cut3D</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/fold2Bloch_help.html"><B>fold2Bloch</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/optic_help.html"><B>Optic</B></A> ');
document.write(' <B> | </B> ');
document.write(' <A href="../users/mrgscr_help.html"><B>Mrgscr</B></A> ');
document.write(' <HR ALIGN=left> ');
